[libpng12] Imported from libpng-1.2.51beta02.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index 2db57c7..7ed2752 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.2.51beta02 - March 1, 2013
+Libpng 1.2.51beta02 - June 18, 2013
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -48,8 +48,9 @@
     in configure.ac
   Changed default value of PNG_USER_CACHE_MAX from 0 to 32767 in pngconf.h.
 
-version 1.2.51beta02 [March 1, 2013]
+version 1.2.51beta02 [June 18, 2013]
   Avoid a possible memory leak in contrib/gregbook/readpng.c
+  Revised libpng.3 so that "doclift" can process it.
 
 (subscription required; visit
 https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CHANGES b/CHANGES
index f293eea..e38b88d 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2784,8 +2784,9 @@
     in configure.ac
   Changed default value of PNG_USER_CACHE_MAX from 0 to 32767 in pngconf.h.
 
-version 1.2.51beta02 [March 1, 2013]
+version 1.2.51beta02 [June 18, 2013]
   Avoid a possible memory leak in contrib/gregbook/readpng.c
+  Revised libpng.3 so that "doclift" can process it.
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/INSTALL b/INSTALL
index 7c21aa0..48ea7e8 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
 
-Installing libpng version 1.2.51beta02 - January 22, 2013
+Installing libpng version 1.2.51beta02 - June 18, 2013
 
 On Unix/Linux and similar systems, you can simply type
 
diff --git a/LICENSE b/LICENSE
index 5c20eb8..79b8947 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.2.51beta02, January 22, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.2.51beta02, June 18, 2013, are
 Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 22, 2013
+June 18, 2013
diff --git a/README b/README
index f487ec0..44736f5 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.2.51beta02 - June 4, 2013 (shared library 12.0)
+README for libpng version 1.2.51beta02 - June 18, 2013 (shared library 12.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/Y2KINFO b/Y2KINFO
index 8560a1d..494264b 100644
--- a/Y2KINFO
+++ b/Y2KINFO
@@ -1,7 +1,7 @@
    Y2K compliance in libpng:
    =========================
 
-      January 22, 2013
+      June 18, 2013
 
       Since the PNG Development group is an ad-hoc body, we can't make
       an official declaration.
diff --git a/libpng-1.2.51beta02.txt b/libpng-1.2.51beta02.txt
index 7e7b22e..75d316b 100644
--- a/libpng-1.2.51beta02.txt
+++ b/libpng-1.2.51beta02.txt
@@ -1,6 +1,6 @@
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.2.51beta02 - April 11, 2013
+ libpng version 1.2.51beta02 - June 18, 2013
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.2.51beta02 - April 11, 2013
+ libpng versions 0.97, January 1998, through 1.2.51beta02 - June 18, 2013
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -2849,7 +2849,7 @@
 and p1 and p2 are parameters that are to be embedded in the string
 according to printf-style formatting directives.  For example,
 
-   png_debug1(2, "foo=%d\n", foo);
+   png_debug1(2, "foo=%d", foo);
 
 is expanded to
 
@@ -3179,7 +3179,7 @@
 
 XIII. Y2K Compliance in libpng
 
-April 11, 2013
+June 18, 2013
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index 551db57..0bedd94 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "April 11, 2013"
+.TH LIBPNG 3 "June 18, 2013"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.2.51beta02
 .SH SYNOPSIS
@@ -342,11 +342,11 @@
 
 \fI\fB
 
-\fBDEPRECATED: void png_info_init (png_infop \fIinfo_ptr\fP\fB);\fP
+\fBDEPRECATED void png_info_init (png_infop \fIinfo_ptr\fP\fB);\fP
 
 \fI\fB
 
-\fBDEPRECATED: void png_info_init_2 (png_infopp \fP\fIptr_ptr\fP\fB, png_size_t \fIpng_info_struct_size\fP\fB);\fP
+\fBDEPRECATED void png_info_init_2 (png_infopp \fP\fIptr_ptr\fP\fB, png_size_t \fIpng_info_struct_size\fP\fB);\fP
 
 \fI\fB
 
@@ -374,7 +374,7 @@
 
 \fI\fB
 
-\fBDEPRECATED: void png_permit_empty_plte (png_structp \fP\fIpng_ptr\fP\fB, int \fIempty_plte_permitted\fP\fB);\fP
+\fBDEPRECATED void png_permit_empty_plte (png_structp \fP\fIpng_ptr\fP\fB, int \fIempty_plte_permitted\fP\fB);\fP
 
 \fI\fB
 
@@ -398,11 +398,11 @@
 
 \fI\fB
 
-\fBDEPRECATED: void png_read_init (png_structp \fIpng_ptr\fP\fB);\fP
+\fBDEPRECATED void png_read_init (png_structp \fIpng_ptr\fP\fB);\fP
 
 \fI\fB
 
-\fBDEPRECATED: void png_read_init_2 (png_structpp \fP\fIptr_ptr\fP\fB, png_const_charp \fP\fIuser_png_ver\fP\fB, png_size_t \fP\fIpng_struct_size\fP\fB, png_size_t \fIpng_info_size\fP\fB);\fP
+\fBDEPRECATED void png_read_init_2 (png_structpp \fP\fIptr_ptr\fP\fB, png_const_charp \fP\fIuser_png_ver\fP\fB, png_size_t \fP\fIpng_struct_size\fP\fB, png_size_t \fIpng_info_size\fP\fB);\fP
 
 \fI\fB
 
@@ -774,11 +774,11 @@
 
 \fI\fB
 
-\fBDEPRECATED: void png_write_init (png_structp \fIpng_ptr\fP\fB);\fP
+\fBDEPRECATED void png_write_init (png_structp \fIpng_ptr\fP\fB);\fP
 
 \fI\fB
 
-\fBDEPRECATED: void png_write_init_2 (png_structpp \fP\fIptr_ptr\fP\fB, png_const_charp \fP\fIuser_png_ver\fP\fB, png_size_t \fP\fIpng_struct_size\fP\fB, png_size_t \fIpng_info_size\fP\fB);\fP
+\fBDEPRECATED void png_write_init_2 (png_structpp \fP\fIptr_ptr\fP\fB, png_const_charp \fP\fIuser_png_ver\fP\fB, png_size_t \fP\fIpng_struct_size\fP\fB, png_size_t \fIpng_info_size\fP\fB);\fP
 
 \fI\fB
 
@@ -821,7 +821,7 @@
 .SH LIBPNG.TXT
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.2.51beta02 - April 11, 2013
+ libpng version 1.2.51beta02 - June 18, 2013
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -832,7 +832,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.2.51beta02 - April 11, 2013
+ libpng versions 0.97, January 1998, through 1.2.51beta02 - June 18, 2013
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -3670,12 +3670,12 @@
 and p1 and p2 are parameters that are to be embedded in the string
 according to printf-style formatting directives.  For example,
 
-   png_debug1(2, "foo=%d\n", foo);
+   png_debug1(2, "foo=%d", foo);
 
 is expanded to
 
    if(PNG_DEBUG > 2)
-     fprintf(PNG_DEBUG_FILE, "foo=%d\n", foo);
+     fprintf(PNG_DEBUG_FILE, "foo=%d\en", foo);
 
 When PNG_DEBUG is defined but is zero, the macros aren't defined, but you
 can still use PNG_DEBUG to control your own debugging:
@@ -4000,7 +4000,7 @@
 
 .SH XIII. Y2K Compliance in libpng
 
-April 11, 2013
+June 18, 2013
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -4385,7 +4385,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.2.51beta02 - April 11, 2013:
+Libpng version 1.2.51beta02 - June 18, 2013:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -4408,7 +4408,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.2.51beta02, April 11, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.2.51beta02, June 18, 2013, are
 Copyright (c) 2004,2006-2008 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -4507,7 +4507,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-April 11, 2013
+June 18, 2013
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 3327406..72efe0f 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "January 22, 2013"
+.TH LIBPNGPF 3 "June 18, 2013"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.2.51beta02
 (private functions)
diff --git a/png.5 b/png.5
index e51d5c6..a41a928 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 22, 2013"
+.TH PNG 5 "June 18, 2013"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 673ce95..0b9fe17 100644
--- a/png.c
+++ b/png.c
@@ -724,13 +724,13 @@
 #else
 #ifdef __STDC__
    return ((png_charp) PNG_STRING_NEWLINE \
-     "libpng version 1.2.51beta02 - January 22, 2013" PNG_STRING_NEWLINE \
+     "libpng version 1.2.51beta02 - June 18, 2013" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2013 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE);
 #else
-      return ((png_charp) "libpng version 1.2.51beta02 - January 22, 2013\
+      return ((png_charp) "libpng version 1.2.51beta02 - June 18, 2013\
       Copyright (c) 1998-2013 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index 6f4cd8f..19e31f7 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.2.51beta02 - January 22, 2013
+ * libpng version 1.2.51beta02 - June 18, 2013
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngset.c b/pngset.c
index e43e458..a865e37 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
 
 /* pngset.c - storage of image information into info struct
  *
- * Last changed in libpng 1.2.51 [January 22, 2013]
+ * Last changed in libpng 1.2.51 [June 18, 2013]
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/scripts/README.txt b/scripts/README.txt
index f1fcd88..ca77a47 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.2.51beta02 - January 22, 2013
+Makefiles for  libpng version 1.2.51beta02 - June 18, 2013
 
  makefile.linux    =>  Linux/ELF makefile
                        (gcc, creates libpng12.so.0.1.2.51beta02)
diff --git a/png.h b/png.h
index 82f49c8..be42971 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.2.51beta02 - January 22, 2013
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -10,7 +10,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.2.51beta02 - January 22, 2013: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -316,7 +316,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.2.51beta02, January 22, 2013, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -428,7 +428,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    January 22, 2013
+ *    June 18, 2013
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -492,7 +492,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.2.51beta02"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.2.51beta02 - January 22, 2013\n"
+   " libpng version 1.2.51beta02 - June 18, 2013\n"
 
 #define PNG_LIBPNG_VER_SONUM   0
 #define PNG_LIBPNG_VER_DLLNUM  13
@@ -1,6 +1,6 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.2.51beta02 - January 22, 2013
+ * libpng version 1.2.51beta02 - June 18, 2013
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -10,7 +10,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.2.51beta02 - January 22, 2013: Glenn
+ *  libpng versions 0.97, January 1998, through 1.2.51beta02 - June 18, 2013: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -316,7 +316,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.2.51beta02, January 22, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.51beta02, June 18, 2013, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5